pub struct CausalTensorWitness;Trait Implementations
Sourceimpl Applicative<CausalTensorWitness> for CausalTensorWitness
impl Applicative<CausalTensorWitness> for CausalTensorWitness
Sourcefn apply<A, B, Func>(
f_ab: CausalTensor<Func>,
f_a: CausalTensor<A>,
) -> CausalTensor<B>where
A: Satisfies<NoConstraint> + Clone,
B: Satisfies<NoConstraint>,
Func: Satisfies<NoConstraint> + FnMut(A) -> B,
fn apply<A, B, Func>(
f_ab: CausalTensor<Func>,
f_a: CausalTensor<A>,
) -> CausalTensor<B>where
A: Satisfies<NoConstraint> + Clone,
B: Satisfies<NoConstraint>,
Func: Satisfies<NoConstraint> + FnMut(A) -> B,
Sourceimpl CoMonad<CausalTensorWitness> for CausalTensorWitness
impl CoMonad<CausalTensorWitness> for CausalTensorWitness
Sourcefn extract<A>(fa: &CausalTensor<A>) -> A
fn extract<A>(fa: &CausalTensor<A>) -> A
Extracts the value at the current focus of the comonadic context. Read more
Sourcefn extend<A, B, Func>(fa: &CausalTensor<A>, f: Func) -> CausalTensor<B>where
Func: FnMut(&CausalTensor<A>) -> B,
A: Satisfies<NoConstraint> + Clone,
B: Satisfies<NoConstraint>,
fn extend<A, B, Func>(fa: &CausalTensor<A>, f: Func) -> CausalTensor<B>where
Func: FnMut(&CausalTensor<A>) -> B,
A: Satisfies<NoConstraint> + Clone,
B: Satisfies<NoConstraint>,
Extends the comonadic context by applying a function to its observed state. Read more
Sourceimpl Foldable<CausalTensorWitness> for CausalTensorWitness
impl Foldable<CausalTensorWitness> for CausalTensorWitness
Sourcefn fold<A, B, Func>(fa: CausalTensor<A>, init: B, f: Func) -> B
fn fold<A, B, Func>(fa: CausalTensor<A>, init: B, f: Func) -> B
Reduces the elements of the structure to a single value by applying a function. Read more
Sourceimpl Functor<CausalTensorWitness> for CausalTensorWitness
impl Functor<CausalTensorWitness> for CausalTensorWitness
Sourcefn fmap<A, B, Func>(m_a: CausalTensor<A>, f: Func) -> CausalTensor<B>
fn fmap<A, B, Func>(m_a: CausalTensor<A>, f: Func) -> CausalTensor<B>
Sourceimpl HKT for CausalTensorWitness
impl HKT for CausalTensorWitness
Sourcetype Constraint = NoConstraint
type Constraint = NoConstraint
The constraint on inner types. Use
NoConstraint for fully polymorphic.Sourcetype Type<T> = CausalTensor<T>
where
T: Satisfies<NoConstraint>
type Type<T> = CausalTensor<T> where T: Satisfies<NoConstraint>
The Generic Associated Type (GAT) that represents the type constructor.
The
<T> is the “hole” in the type constructor (e.g., Option<T>). Read moreSourceimpl Monad<CausalTensorWitness> for CausalTensorWitness
impl Monad<CausalTensorWitness> for CausalTensorWitness
Sourcefn bind<A, B, Func>(m_a: CausalTensor<A>, f: Func) -> CausalTensor<B>where
A: Satisfies<NoConstraint>,
B: Satisfies<NoConstraint>,
Func: FnMut(A) -> <Self as HKT>::Type<B>,
fn bind<A, B, Func>(m_a: CausalTensor<A>, f: Func) -> CausalTensor<B>where
A: Satisfies<NoConstraint>,
B: Satisfies<NoConstraint>,
Func: FnMut(A) -> <Self as HKT>::Type<B>,
Chains a computation from an effectful value, flattening the result.
This is the core sequencing operation of a Monad. Read more
Sourceimpl Pure<CausalTensorWitness> for CausalTensorWitness
impl Pure<CausalTensorWitness> for CausalTensorWitness
Sourcefn pure<T>(value: T) -> CausalTensor<T>where
T: Satisfies<NoConstraint>,
fn pure<T>(value: T) -> CausalTensor<T>where
T: Satisfies<NoConstraint>,
Lifts a pure value into the context
F::Type<T>. Read moreAuto Trait Implementations
impl Freeze for CausalTensorWitness
impl RefUnwindSafe for CausalTensorWitness
impl Send for CausalTensorWitness
impl Sync for CausalTensorWitness
impl Unpin for CausalTensorWitness
impl UnsafeUnpin for CausalTensorWitness
impl UnwindSafe for CausalTensorWitness